@@ -7,13 +7,13 @@ from helpers import allclose, eik2d
     "sources, points, gzref, gxref",
     (
         ([0.0, 0.0], [0.0, 0.0], 0.0, 0.0),
-        ([3.5, 3.5], [0.0, 0.0], -0.64858483, -0.64858483),
+        ([3.5, 3.5], [0.0, 0.0], -0.70710678, -0.70710678),
         ([0.0, 0.0], [-1.0, -1.0], numpy.nan, numpy.nan),
         (
             [0.0, 0.0],
-            [[0.0, 0.0], [15.0, 0.0], [15.0, 15.0], [0.0, 15.0],],
-            [0.0, 1.0, 0.69457650, 0.0],
-            [0.0, 0.0, 0.69457650, 1.0],
+            [[0.0, 0.0], [15.0, 0.0], [15.0, 15.0], [0.0, 15.0]],
+            [0.0, 1.0, 0.70710678, 0.0],
+            [0.0, 0.0, 0.70710678, 1.0],
         ),
     ),
 )
